Shared trait definitions for common comprehensive resources
This crate defines traits that are designed to be implemented and exported
by one Resource and consumed by another, so that the implementor and
consumer do not depend on one another.
Modules
- http_
diag - Shared trait definition for exposing diagnostics on a common HTTP server