pub type Service = BoxCloneSyncService<Request<Body>, Response<Body>, Infallible>;Expand description
The type or tower Service that handlers should provide.
This unfortunately has to be a concrete type in order for
HttpDiagHandlerInstaller to be dyn-compatible, so implementors will
need to convert services to this type.
Aliased Type
pub struct Service(/* private fields */);